#
# spec file for package ghc-unicode-data
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name unicode-data
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.4.0.1
Release:        3.8
Summary:        Access Unicode Character Database (UCD)
License:        Apache-2.0
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
Source1:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/revision/1.cabal#/%{pkg_name}.cabal
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-rpm-macros
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-hspec-devel
BuildRequires:  ghc-hspec-prof
%endif

%description
'unicode-data' provides Haskell APIs to efficiently access the
<https://www.unicode.org/ucd/ Unicode character database> (UCD).
Performance is the primary goal in the design of this package.

The Haskell data structures are generated programmatically from the UCD files.
The latest Unicode version supported by this library is
'<https://www.unicode.org/versions/Unicode15.0.0/ 15.0.0>'.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}
cp -p %{SOURCE1} %{pkg_name}.cabal

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc Changelog.md README.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Tue Jan 17 2023 Peter Simons <psimons@suse.com>
- Update unicode-data to version 0.4.0.1 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Sat Dec 17 2022 Peter Simons <psimons@suse.com>
- Update unicode-data to version 0.4.0.1.
  [#]# 0.4.0.1 (December 2022)
  - Fix [Unicode blocks handling on big-endian architectures](https://github.com/composewell/unicode-data/issues/97).
* Thu Oct 13 2022 Peter Simons <psimons@suse.com>
- Update unicode-data to version 0.4.0.
  [#]# 0.4.0 (September 2022)
  - Update to [Unicode 15.0.0](https://www.unicode.org/versions/Unicode15.0.0/).
* Wed Sep 28 2022 Peter Simons <psimons@suse.com>
- Update unicode-data to version 0.3.1.
  [#]# 0.3.1 (September 2022)
  - Added full case conversions to `Unicode.Char.Case`:
  - Case folding: `caseFoldMapping` and `toCaseFoldString`.
  - Lower case: `lowerCaseMapping` and `toLowerString`.
  - Upper case: `upperCaseMapping` and `toUpperString`.
  - Title case: `titleCaseMapping` and `toTitleString`.
  - Stream mechanism: `Unfold` and `Step`.
  - Added `isNumeric`, `numericValue` and `integerValue`
    to `Unicode.Char.Numeric`.
  - Added the module `Unicode.Char.General.Blocks`.
  - Add compatibility module:
  - `Unicode.Char.Numeric.Compat`
  [#]## Deprecations
  - `Unicode.Char.Numeric.isNumber`: it will be replaced by `isNumeric`
    in a _future_ version of this package.
    Use the function in `Unicode.Char.Numeric.Compat` instead.
* Mon Sep 12 2022 Peter Simons <psimons@suse.com>
- Update unicode-data to version 0.3.0 revision 2.
  Upstream has revised the Cabal build instructions on Hackage.
* Sun Jan  9 2022 Peter Simons <psimons@suse.com>
- Update unicode-data to version 0.3.0 revision 1.
  [#]# 0.3.0 (December 2021)
  - Support for big-endian architectures.
  - Added `unicodeVersion`.
  - Added `GeneralCategory` data type and corresponding `generalCategoryAbbr`,
    `generalCategory` functions.
  - Added the following functions to `Unicode.Char.General`:
    `isAlphabetic`, `isAlphaNum`,
    `isControl`, `isMark`, `isPrint`, `isPunctuation`, `isSeparator`,
    `isSymbol` and `isWhiteSpace`.
  - Added the module `Unicode.Char.Numeric`.
  - Add compatibility modules:
  - `Unicode.Char.General.Compat`
  - `Unicode.Char.Case.Compat`
    These modules are compatible with `base:Data.Char`.
  - Re-export some functions from `Data.Char` in order to make `Unicode.Char`
    a drop-in replacement in a _future_ version of this package.
  - Drop support for GHC 7.10.3
  [#]## Deprecations
  - In `Unicode.Char.Case`:
  - `isUpper`: use `isUpperCase` instead.
  - `isLower`: use `isLowerCase` instead.
  - In `Unicode.Char.General`:
  - `isLetter`: use `isAlphabetic` instead.
  - `isSpace`: use `isWhiteSpace` instead.
  - In `Unicode.Char`: same as hereinabove. These functions will be replaced in a
    _future_ release with the functions with the same names from
    `Unicode.Char.Case.Compat` and `Unicode.Char.General.Compat`.
* Sat Nov 20 2021 psimons@suse.com
- Update unicode-data to version 0.2.0.
  [#]# 0.2.0 (November 2021)
  * Update to [Unicode 14.0.0](https://www.unicode.org/versions/Unicode14.0.0/).
  * Add `Unicode.Char.Identifiers` supporting Unicode Identifier and Pattern
    Syntax.
* Fri Jul 23 2021 psimons@suse.com
- Add unicode-data at version 0.1.0.1.
